@@ -32,7 +32,7 @@ use std::str;
 
 const BUILD_OUT_FILE: &str = "constants.rs";
 const SOURCE_DIR: &str = "./src";
-const TOML: &'static str = include_str!("Cargo.toml");
+const CARGO_TOML: &'static str = include_str!("Cargo.toml");
 
 fn main() {
     let dest_path = Path::new(SOURCE_DIR).join(Path::new(BUILD_OUT_FILE));
@@ -98,11 +98,15 @@ fn main() {
         .as_str();
     write_str_constant_to_file(&mut file, "COMPILER_VERSION", &compiler_version);
 
-    let re = Regex::new("image.*version = \"(.*)\",").unwrap();
-    let libpng_version = format!(
-        "image-{}",
-        re.captures(TOML).unwrap().get(1).unwrap().as_str()
-    );
+    let re = Regex::new("image(?:.|\n)*version = \"(.*)\"[,\n]").unwrap();
+    let libpng_capture = re.captures(CARGO_TOML);
+    let libpng_capture_s = if re.captures(CARGO_TOML).is_some() {
+        libpng_capture.unwrap().get(1).unwrap().as_str()
+    } else {
+        "undefined"
+    };
+    let libpng_version = format!("image-{}", libpng_capture_s);
+
     write_str_constant_to_file(&mut file, "LIBPNG_VERSION", &libpng_version);
 
     let mut features = vec!["cpu"];
